Create the schemr class, which holds the palette and image data
imageAn array of dimension (Image width) by (Image height) by (3 colour channels) that contains the data of the original image
clustered_imageAn array of dimension (Image width) by (Image height) by (3 colour channels) that contains the data of the image with clustered colour blocks
paletteA character vector that contains the colours of the resulting colour palette
print(x)Print the colour palette.